@@ -1,4 +1,4 @@
-/**
+/***********************************************************************
  * \file animationattribute.cpp
  * 
  * This class will handle the Animation attributes.
@@ -8,9 +8,12 @@
  * If the Attribute is a simple type (int, float, double etc)
  * then the 
  *
+ *   Created :
+ *        by : Varol Okan using Kate
+ * Copyright : (c) Varol Okan
+ *   License : GPL v 2.0
  *
- *
- */
+ ***********************************************************************/
 
 #include "animationattribute.h"
 
@@ -143,6 +146,20 @@ void AnimationAttribute::initMe (long iFrames, QString qsName)
 	m_arrayInts    = NULL;
 	m_qsName       = qsName;
 	m_iMaxFrames   = iFrames;
+	m_bNeedRefresh = true;
+}
+
+/**
+ * This function returns wether we will need to refresh the imageObject or not.
+ */
+bool AnimationAttribute::needRefresh ( )
+{
+  return m_bNeedRefresh;
+}
+
+void AnimationAttribute::setNeedRefresh ( bool bRefresh )
+{
+  m_bNeedRefresh = bRefresh;
 }
 
 /**
@@ -171,9 +188,9 @@ int AnimationAttribute::iValue (long iFrame)
 bool AnimationAttribute::bValue (long iFrame)
 {
 	if (!m_arrayBools)
-		return -1;
+		return false;
 	if ( ( iFrame < 0 ) || ( iFrame > m_iMaxFrames ) )
-		return -1;
+		return false;
 	return (m_arrayBools[iFrame]);
 }
 
@@ -228,41 +245,42 @@ long AnimationAttribute::maxFrames ()
  * 
  * @param iFrame The frame number for which we are getting the value from the array.
  */
-void AnimationAttribute::setValue (long iFrame)
+bool AnimationAttribute::setValue (long iFrame)
 {
 	if ( ( ! m_arrayFloats ) && ( ! m_arrayInts ) &&
 	     ( ! m_arrayBools )  && ( ! m_arrayDoubles ) )
-		return;
+		return false;
 	if ( ( iFrame < 0 ) || ( iFrame > m_iMaxFrames ) )
-		return;
+		return false;
 
 	// Do we have an integer array ???
 	if (m_arrayInts && m_piValue)	{
 		if (m_arrayInts[iFrame] == -1)
-			return;
+			return false;
 		*m_piValue = m_arrayInts[iFrame];
 	} // or is it a
 	else if (m_arrayInts && m_setFunction)	{
 		if (m_arrayInts[iFrame] == -1)
-			return;
+			return false;
 		(*m_setFunction)(m_arrayInts[iFrame]);
 	}
 
 	else if (m_arrayFloats && m_pfValue)	{
 		if (m_arrayFloats[iFrame] == -9999.99f)
-			return;
+			return false;
 		*m_pfValue = m_arrayFloats[iFrame];
 	}
 	else if (m_arrayDoubles && m_pdValue)	{
 		if (m_arrayDoubles[iFrame] == -9999.99f)
-			return;
+			return false;
 		*m_pdValue = m_arrayDoubles[iFrame];
 	}
 	else if (m_arrayStrings && m_pqsValue)	{
 		if (m_arrayStrings[iFrame].isEmpty())
-			return;
+			return false;
 		*m_pqsValue = m_arrayStrings[iFrame];
 	}
+	return m_bNeedRefresh;
 }
 
 /** 
