@@ -49,7 +49,6 @@ ButtonPreview::~ButtonPreview()
     delete m_pUndoBuffer;
 
  uint t;
- MenuObject *pObject;
  for ( t=0; t<m_listMenuObjects.count ( ); t++ )
    delete m_listMenuObjects.at ( t );
 
@@ -510,14 +509,21 @@ void ButtonPreview::setBackground ( QPixmap &thePixmap )
     QLabel::setPixmap ( thePixmap );
 }
 
-void ButtonPreview::drawBackground ( QPixmap &thePixmap )
+void ButtonPreview::drawBackground ( QPixmap &thePixmap, MenuObject *pOmitMe )
 {
   uint t;
+  MenuObject *pObject;
   thePixmap = QPixmap ( m_backgroundPixmap );
   QPainter thePainter ( &thePixmap  );
   // First lets imprint the visibleRegionR - rect (if neccesarry).
   drawVisibleRegion   ( &thePainter );
   // And here we draw the objects ...
-  for (t=0;t<m_listMenuObjects.count();t++)
-    m_listMenuObjects.at(t)->drawContents (&thePainter);
+  for  ( t=0; t<m_listMenuObjects.count ( ); t++ ) {
+    pObject = m_listMenuObjects.at ( t );
+    if ( ! pObject )
+      continue;
+    if ( pOmitMe && ( pOmitMe == pObject ) )
+      continue;
+    pObject->drawContents ( &thePainter );
+  }
 }
