@@ -278,12 +278,17 @@ void DialogButton::initMultiple ( )
 
   QStringList list = m_pClonedButton->getPlayMultipleList ( );
   if ( list.count ( ) > 0 ) {
-    QString qsText = tr ( "<FONT COLOR=\"RED\"><B>Play %1" ).arg ( list.count ( ) );
+    int iTargetCount = list.count ( );
+    QString qsText;
     QString qsLast = list.last ( );
     QStringList lastList = QStringList::split ( STRING_SEPARATOR, qsLast );
     qsText += m_pClonedButton->getLoopMultiple ( ) ? tr (  ", Loop"   ) : "";
-    qsText += ( lastList.count ( ) == 2 ) ? tr ( ", to Menu" ) : "";
+    if ( lastList.count ( ) == 2 )  { // Last target is to a Menu
+      qsText += tr ( ", to Menu" );
+      iTargetCount --;
+    }
     qsText += "</B></FONT>";
+    qsText  = "<FONT COLOR=\"RED\"><B>" + tr ( "Play %1" ).arg ( iTargetCount ) + qsText; 
     m_pLabelMultiple->setText ( qsText );
   }
   else
