@@ -509,7 +509,7 @@ QString DialogCreateTemplate::findGuiSU ( )
   uint t;
   QString qsReturn;
   QString qsTmpOut = QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) );
-  char *arraySUs[3] = {"kdesu", "xsu", "gnomesu"};
+  char arraySUs[3][10] = {"kdesu", "xsu", "gnomesu"};
   QFileInfo fileInfo( qsTmpOut );
   for (t=0;t<3;t++)	{
     // the next check is to see if we can find kdesu
@@ -1022,7 +1022,7 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
   QString                 qsFileName;
   ButtonObject            tempButton, *pButton;
   MenuObject            * pObject, *pTempObject;
-  CDVDMenuInterface     * pInterface      = m_pDVDMenu->getInterface         ( );;
+  CDVDMenuInterface     * pInterface      = m_pDVDMenu->getInterface         ( );
   MenuPreview           * pMenuPreview    = m_pDVDMenu->getMenuPreview       ( );
   QValueList<MenuObject *>listOfDropZones = m_pFrameProperties->getDropZones ( );
   qsFileName = qsTemplatePath + "/thumbnail.png";
@@ -1032,14 +1032,14 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
   
   iWidth  = 720;
   iHeight = 480;
-  if ( pInterface && ! pInterface->backgroundImage.isNull ( ) ) {
+  if ( ! pInterface->backgroundImage.isNull ( ) ) {
     iWidth  = pInterface->backgroundImage.width  ( );
     iHeight = pInterface->backgroundImage.height ( );
   }
   
   // The background image is generated by using the background and overlaying all MenuObject
   qsFileName = qsTemplatePath + "/background/background00000.jpg";
-  if ( pInterface && pInterface->backgroundImage.isNull ( ) ) {
+  if ( pInterface->backgroundImage.isNull ( ) ) {
     theBackground = QPixmap ( iWidth, iHeight );
     theBackground.fill ( pInterface->pgcColors[0].color ( ) );
   }
@@ -1053,7 +1053,7 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
     theImage.save   ( qsFileName, "JPEG", 100 );    
   }
 
-  if ( pInterface && ! pInterface->qsMovieFileName.isNull ( ) ) {
+  if ( ! pInterface->qsMovieFileName.isEmpty ( ) ) {
     QString qsCommand;
     qsCommand = QString ( "cp %1 %2/background/" ).arg ( pInterface->qsMovieFileName ).arg ( qsTemplatePath );
     iRet = system ( qsCommand.ascii ( ) );
