@@ -162,11 +162,12 @@ class DialogFiles : public uiDialogFiles
   // to be executed in timerEvent.
   class WorkWaiting  {
   public:
-     WorkWaiting ( QIconViewItem *, QImage * );
+    WorkWaiting ( QIconViewItem *, QImage *, bool );
     ~WorkWaiting ( );
     
     QIconViewItem *pItem;
     QImage        *pImage;
+    bool           bMarkIcon;
   };
 
   class Thumbs {
@@ -187,7 +188,7 @@ public: // public strctures ...
   DialogFiles ( SourceToolBar *, const char *n=0, WFlags f=0 );
   virtual ~DialogFiles ( );
 
-  void initWork      ( QIconViewItem *,  QImage * );
+  void initWork      ( QIconViewItem *, QImage *, bool );
   bool initScanDV    ( Thumbs * );
   void addProgress   ( int );
   uint thumbnailSize ( );
@@ -279,6 +280,12 @@ protected slots:
   virtual void slotVirtualContextMenu    ( QListViewItem *, const QPoint &, int );
 
 private:
+  static bool m_bStars;
+  static bool m_bName;
+  static bool m_bDate;
+  static bool m_bLength;
+  static int  m_iThumbnailSize;
+
   QTimer   *m_pTimerAutoOpen;
   QTimer   *m_pTimerScanDir;
   QTimer   *m_pTimerThumbing;
@@ -299,7 +306,7 @@ private:
   bool      m_bCanClose;
   bool      m_bCanChangeIcons;
   uint      m_iProgress;
-  uint      m_iThumbnailSize;
+  //uint      m_iThumbnailSize;
   uint      m_iMultiThumbNumber;
 
   QMutex    m_mutex;
