@@ -363,7 +363,7 @@ bool DVDAuthor::createJumpTable ( )
 
       if ( pInfo ) {  // button to a Video
 	pTitleset = findTitleset ( pInfo );
-	// Lastly if we have a PlayMultiple-button,
+	// If we have a PlayMultiple-button,
 	// we have to create new JumpTableEntries, one for each target.
 	createPlayMultiple ( pButton, pMenu, ++iPlayMultipleIdx );
 
@@ -526,7 +526,7 @@ void DVDAuthor::createPlayMultiple ( ButtonObject *pButton, DVDMenu *pDVDMenu, u
       continue;
 
     pJumpTableEntry = new JumpTable;
-    // +2 because the buttonAction has not been added to the list
+    // +1 because the buttonAction has not been added to the list
     pJumpTableEntry->iJumpIndex = pTargetTitleset->listJumpTable.count ( ) + 1;
     pJumpTableEntry->iTitle     = pTargetTitleset->findTitle   ( pTargetInfo );
     pJumpTableEntry->iChapter   = pTargetTitleset->getChapters ( pTargetInfo, listPlayMultiple[t] ) + 
@@ -556,7 +556,7 @@ void DVDAuthor::createPlayMultiple ( ButtonObject *pButton, DVDMenu *pDVDMenu, u
     
     pMultiple->addPlayMultiple ( qsPlayMultiple );
     if ( pJumpTableEntry )
-      pTargetTitleset->listJumpTable.append ( pJumpTableEntry );
+         pTargetTitleset->listJumpTable.append ( pJumpTableEntry );
     
     // lastly we set the new sourceTitleset and sourceInfo for the newxt loop
     pSourceTitleset = pTargetTitleset;
@@ -855,6 +855,7 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFile
 
   // The first way is if none of the info's has and post or pre
   // command. All videos are stored in one title ( pgc )
+
   if ( ! temp.checkForPrePostCommands ( pEntry, true ) ) { // true == the fist pPgc can have a pre and the last is allowed to have a post command
     pPgc = pTitle->addPgc ( );
     return addToTitleset  ( pPgc, pEntry );
@@ -869,7 +870,7 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFile
     addToTitleset ( pPgc, pEntry->listFileInfos[i] );
     // just in case to ensure something is happening afterwards.
     if ( pPgc->post.value.isEmpty ( ) )
-      pPgc->post.value = "{ g2 = 0; call vmgm menu entry title; } ";
+         pPgc->post.value = " { g2 = 0; call vmgm menu entry title; } ";
   }
   //  if ( pPgc && pPgc->post.value.isEmpty ( ) )
   //    pPgc->post.value = QString (" { g2 = 0; call vmgm menu entry title; } ");
@@ -887,6 +888,8 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileInfo
   if ( pMultiple )
     pPgc->post.value = pMultiple->getPostCommand ( );
 
+  //printf ( "Line 891 : fileName<%s> multi:Post <%s>\n", pInfo->qsFileName.ascii(), pMultiple ? pMultiple->getPostCommand ( ).ascii ( ) : "NULL" );
+
   pPgc->post.value  += pInfo->qsPostCommand;
 
   pVob = pPgc->addVob ( );
@@ -1310,7 +1313,7 @@ PlayMultiple *DVDAuthor::findMultiple ( SourceFileInfo *pInfo, bool bTarget )
     else
       pListInfo = m_listPlayMultiple[t]->pSourceInfo;
 
-    if (  pListInfo == pInfo )
+    if ( pListInfo == pInfo )
       return m_listPlayMultiple[t];
   }
   return NULL;
@@ -2066,12 +2069,9 @@ bool ExportTitleset::checkForPrePostCommands ( SourceFileEntry *pEntry, bool bIg
   // bIgnoreFirstLast will ignore the pre for the first SourceFileInfo
   // and the post command for the last SourceFileInfo.
 
-  // if we ignore first pre and last post AND there is only one SourceFileInfo in the list then ...
-  if ( ( bIgnoreFirstLast ) && ( pEntry->listFileInfos.count() < 1 ) )
-    return false;
-  
   uint iCount = pEntry->listFileInfos.count();
-  SourceFileInfo *pInfo;
+  SourceFileInfo *pInfo     = NULL;
+  PlayMultiple   *pMultiple = NULL;
   for ( i=0; i<iCount; i++ ) {
     pInfo = pEntry->listFileInfos[i];
 
@@ -2079,6 +2079,7 @@ bool ExportTitleset::checkForPrePostCommands ( SourceFileEntry *pEntry, bool bIg
       // check first SourceFileInfo
       if ( ( i == 0 ) && ( ! pInfo->qsPostCommand.isEmpty () ) )
 	return true;
+
       // check last SourceFileInfo
       else if ( ( i == iCount - 1 ) && ( ! pInfo->qsPreCommand.isEmpty  () ) )
 	return true;
@@ -2090,7 +2091,7 @@ bool ExportTitleset::checkForPrePostCommands ( SourceFileEntry *pEntry, bool bIg
     else if ( ( ! pInfo->qsPreCommand.isEmpty  ( ) ) || 
 	      ( ! pInfo->qsPostCommand.isEmpty ( ) ) )
       return true;
-    if ( ( pExportDVDAuthor ) && ( pExportDVDAuthor->findMultiple ( pInfo, true ) ) )
+    if ( ( pExportDVDAuthor ) && ( pExportDVDAuthor->findMultiple ( pInfo, false ) ) )
       return true;
   }
 
