@@ -178,8 +178,8 @@ bool DVDAuthor::buildFromDVDAuthorXML ( CXmlDVDAuthor *pDVDAuthor, QValueList<CX
 
   // At this point we should have build a list of DVDMenu - objects 
   // and should be ready to parse the spumux files to assign some missing attributes
-  for ( t=0;t<spumuxList.count();t++) {
-    if ( ! buildFromSpumuxXML ( spumuxList[t] ) ) ;
+  for ( t=0; t<spumuxList.count ( ); t++ )  {
+    if ( ! buildFromSpumuxXML ( spumuxList[t] ) ) t=t;
     //      return false;
   }
 
