@@ -676,65 +676,6 @@ MenuObject *MenuPreview::insertDraggedThumbnail ( QDropEvent *pDropEvent, QImage
   return NULL;
 }
 
-/*
-MenuObject *MenuPreview::insertDraggedThumbnail ( QDropEvent *pDropEvent, QImage &theImage )
-{
-  // This function is called when a drop event from the Library dialog occured.
-  // returns either an ImageObject or a ButtonObject
-  QWidget *pDropParent = pDropEvent->source ( );
-  // Just to make sure ...
-  if ( pDropParent ) {
-    pDropParent = pDropParent->parentWidget ( );
-    if ( pDropParent && ( pDropParent->isA  ( "QIconView" ) ) ) {
-      ImageObject *pImageObject = (ImageObject *)insertDraggedImage ( pDropEvent, theImage );
-      pImageObject->manipulator  ( ).listColorKeys.append ( new ImageManipulator::colorKeying ( qRgb ( 254, 255, 254 ), 0.0f ) );
-      pImageObject->updatePixmap ( );
-      if ( DialogLibrary::m_bCreateButtonMask ) {
-	ShadowObject *pMask, *pNewSelected, *pNewHighlighted;
-	ButtonObject *pButtonObject = new ButtonObject ( this );
-	QString qsAction ( "jump+-+vmgm+-+" );
-	// First we remove the ImageObject ( the one we just added )
-	m_listMenuObjects.remove ( pImageObject );
-	
-	// Next we create a MaskObject
-	pMask = new ShadowObject ( pImageObject, this );
-	pMask->setType   ( ShadowObject::TYPE_MASK );
-	pMask->setRect   ( pImageObject->rect ( ) );
-	pMask->setCutOff ( 0.0f, 0.0f );
-	pMask->setBlur   ( 0 );
-	pImageObject->setCreateMask ( true );
-
-	// Now we generate two copies ...
-	pNewSelected    = (ShadowObject *)pMask; //->clone ( pImageObject, this );
-	pNewHighlighted = (ShadowObject *)pMask->clone ( pImageObject, this );
-	pNewSelected    ->updateShadow ( true );
-	pNewHighlighted ->updateShadow ( true );
-	// And last we connect the signals
-	//	connectStdSlots ( pNewSelected,     true );
-	//	connectStdSlots ( pNewHighlighted,  true );
-
-	pButtonObject->appendNormal      ( pImageObject    );
-	pButtonObject->appendSelected    ( pNewSelected    );
-	pButtonObject->appendHighlighted ( pNewHighlighted );
-
-	pButtonObject->setName   ( newButtonName ( ) );
-	pButtonObject->setAction ( qsAction );
-
-	// and here we append the button object as a new item in the MenuObject list.
-	m_listMenuObjects.append ( pButtonObject );
-	m_pActiveObject = NULL;
-
-	// And finally we connect everything ...
-	connectStdSlots ( pButtonObject, true );
-	return pButtonObject;
-      }
-      else  // Here we only create an ImageObject, no button.
-	return pImageObject;
-    }
-  }
-  return NULL;
-}
- */
 MenuObject *MenuPreview::insertDraggedText (QDropEvent *pEvent, QString &theText )
 {
 	QRect rect;
@@ -774,10 +715,10 @@ MenuObject *MenuPreview::insertDraggedObject (QDropEvent *pDropEvent, QImage &th
 		if ( pSourceFileInfo)	// Okay here we split between adding one button
 			pMenuObject = insertDraggedSourceInfo  (pDropEvent, theImage);	// ButtonObject
 		else	// Or we dragged the full SourceEntry and will use the defined Layout
-			if (pSourceFileEntry->listFileInfos.count() == 1)	// Now only one movie in the Entry ... Booooring ...
+			if (pSourceFileEntry->listFileInfos.count() == 1) // Now only one movie in the Entry ... Booooring ...
 				pMenuObject = insertDraggedSourceInfo(pDropEvent, theImage);	// ButtonObject
 			else
-				pMenuObject = insertDraggedSourceInfo(pDropEvent, theImage);	// Temp solution ...
+				pMenuObject = insertDraggedSourceInfo(pDropEvent, theImage);	//
 // FIXME: 
 // For now we defer this to the next major release so we can release 0.1.5 some time
 // This is supposed to create a whole bunch of menus inclusive backgroud and buttons.
@@ -792,13 +733,10 @@ MenuObject *MenuPreview::insertDraggedObject (QDropEvent *pDropEvent, QImage &th
 
 MenuObject *MenuPreview::insertDraggedSourceEntry(QDropEvent *pDropEvent, QImage &)
 {
-// FIXME: This function should be handled in DVDAuthor as it will create additional menus.
 	uint t;
 	ObjectCollection *pObjectCollection = new ObjectCollection;
 	// The wizard will take care of the spacing plus the overlay
 	LayoutWizard *pWizard = new LayoutWizard;
-//	pWizard->
-
 
 	ButtonObject *pButtonObject = NULL;
 	// Note that at this point we KNOW that the source is coming from the ListViewAllSources - toolbar !!!
@@ -1064,7 +1002,8 @@ MenuObject *MenuPreview::insertDraggedSourceInfo(QDropEvent *pDropEvent, QImage
 	m_listMenuObjects.append(pButtonObject);
 
 	// And finally we connect everything ...
-	connectStdSlots ( pButtonObject, true );
+	connectStdSlots ( pButtonObject, false );
+	// disconnect ( pMenuObject );
 	// After all of this we also want to create a text object ...
 	QString qsWhatDidWeDragg = fileInfo.baseName();
 	insertDraggedText (NULL, qsWhatDidWeDragg);
@@ -1420,40 +1359,48 @@ MenuObject *MenuPreview::createFrameObject(bool bShowDialog)
 	return pFrameObject;
 }
 
-MenuObject *MenuPreview::createTextObject(bool bShowDialog)
+MenuObject *MenuPreview::createTextObject ( bool bShowDialog )
 {
 	TextObject *pTextObject = NULL;
-	if (bShowDialog)	{
+	if ( bShowDialog )  {
 		DialogTextFont fontDialog ( this );
-		fontDialog.setRect  ( m_rectCurrentObject );
-		if (fontDialog.exec ( ) == QDialog::Rejected )
+		fontDialog.setRect   (   m_rectCurrentObject  );
+		if ( fontDialog.exec ( ) == QDialog::Rejected )
 			return NULL;
 
-		pTextObject = new TextObject (this);
-		QString qsText = fontDialog.getText();
-		pTextObject->setRect (fontDialog.getRect());
-//		pTextObject->setRect (m_rectCurrentObject);
-		pTextObject->setFont (fontDialog.getFont());
-		pTextObject->setText (qsText);
-		pTextObject->setAnimation ( fontDialog.getAnimation ( ) );
-		pTextObject->setTextAlign ( fontDialog.getTextAlign ( ) );
-		pTextObject->setBackgroundColor (fontDialog.getBackgroundColor());
-		pTextObject->setForegroundColor (fontDialog.getForegroundColor());
-		pTextObject->modifiers ()->fTransparency = fontDialog.getTransparency();
+		pTextObject    = new TextObject (  this  );
+		QString qsText = fontDialog.getText (    );
+		pTextObject->setText            ( qsText );
+//		pTextObject->setRect            ( m_rectCurrentObject );
+		pTextObject->setRect            ( fontDialog.getRect ( ) );
+		pTextObject->setFont            ( fontDialog.getFont ( ) );
+		pTextObject->setAnimation       ( fontDialog.getAnimation ( ) );
+		pTextObject->setTextAlign       ( fontDialog.getTextAlign ( ) );
+		pTextObject->setBackgroundColor ( fontDialog.getBackgroundColor ( ) );
+		pTextObject->setForegroundColor ( fontDialog.getForegroundColor ( ) );
+		pTextObject->modifiers ( )->fTransparency = fontDialog.getTransparency ( );
 		// Checks wether the user wants to fit the size of the button to the text or not.
-		if (fontDialog.getFit())	{
-			QRect rect = pTextObject->rect();
-			rect.setWidth (1);
-			rect.setHeight(1);
-			pTextObject->setRect(rect);
+		if ( fontDialog.getFit ( ) )  {
+			QRect rect = pTextObject->rect ( );
+			rect.setWidth  ( 1 );
+			rect.setHeight ( 1 );
+			pTextObject->setRect      ( rect  );
+			pTextObject->setWordBreak ( false ); // allows to keep the line intact
 		}
-		m_listMenuObjects.append (pTextObject);
-		emit (signalUpdateStructure());
-		updatePixmap();
-		pTextObject->update ();
+		m_listMenuObjects.append     ( pTextObject );
+		emit ( signalUpdateStructure ( ) );
+
+		QRect orig = pTextObject->rect ( );
+		updatePixmap ( );
+		pTextObject->update   ( );
+		if ( rect ( )  !=  orig )  {  // if the rect has changed ...
+		  updatePixmap        ( );
+		  pTextObject->update ( );
+		}
+		pTextObject->setWordBreak ( true );
 	}
 	else
-		pTextObject = new TextObject (this);
+		pTextObject = new TextObject ( this );
 
 	// Here we connect the signal to the slot ...
 	connectStdSlots ( pTextObject, true );
