@@ -319,7 +319,7 @@ void MenuSlide::animate ( unsigned long iFrameNumber )
 {
   int t, iImageCount, iStartImage, iEndImage, iImageFrames;
   int iImageWidth, iWidth, iImageHeight, iHeight;
-  int iStartFrame, iEndFrame;
+  //int iStartFrame, iEndFrame;
   float   fDeltaZoom, fFPS = 25.0f;
   QImage  theImage;
   QPixmap thePixmap;
