@@ -14,6 +14,7 @@
 *****************************************************************************/
 #include <iostream>
 #include <sys/stat.h>
+#include <stdlib.h>
 
 #include <qsignalmapper.h>
 #include <qstylefactory.h>
@@ -125,29 +126,38 @@ QDVDAuthor::~QDVDAuthor ()
   uint t;
   SaveIni ();
 
-  // This might not be needed since the destructor of the Widget takes care of this ... 
+  // This might not be needed since the destructor of the Widget takes care of this ...
   delete m_pSourceToolbar;
-  delete m_pStructureToolbar;
   if ( m_pDialogExecute )
-    delete m_pDialogExecute;
+      delete m_pDialogExecute;
   if ( m_pDialogLibrary )
-    delete m_pDialogLibrary;
+      delete m_pDialogLibrary;
   for (t=0;t<Global::listToolsPaths.count();t++)
-    delete Global::listToolsPaths[t];
+      delete Global::listToolsPaths[t];
   for (t=0;t<m_listHistoryPix.count();t++)
-    delete m_listHistoryPix[t];
+      delete m_listHistoryPix[t];
   m_iAutosave = 0;
   setAutosave ();	// Note : must be done AFTER calling SaveIni () ...
 
+  // Okay let us start with deleting the SubMenus ...
+  for ( t=0; t<m_listDVDMenus.count ( ); t++ )
+    delete m_listDVDMenus[t];
+  m_listDVDMenus.clear ( );
+  
+  // Here we delete the Main VMGM - menu ...
+  delete m_pVMGMenu;
+  m_pVMGMenu = NULL;
+
   delete m_pActionToolbarNew;
   delete m_pActionToolbarOpen;
   delete m_pActionToolbarSave;
   delete m_pActionToolbarSaveAs;
   delete m_pActionToolbarExit;
   delete m_pToolbar;
+  delete m_pStructureToolbar;
 
   // Just for good measure ...
-  Global::listToolsPaths.clear();
+  Global::listToolsPaths.clear ( );
 }
 
 void QDVDAuthor::initMe()
@@ -659,6 +669,11 @@ SourceFileEntry *QDVDAuthor::getSourceEntryByDisplayName(QString &qsDisplayName)
 	return NULL;
 }
 
+void QDVDAuthor::editSourceFileInfo ( SourceFileInfo *pInfo )
+{
+  m_pSourceToolbar->editSourceFileInfo ( pInfo );
+}
+
 void QDVDAuthor::updateSourceFileInfo ( SourceFileInfo *pInfo )
 {
   m_pSourceToolbar->updateListViewItem ( pInfo );
