@@ -58,8 +58,8 @@ class QDVDAuthor : public CFormMain
 	Q_OBJECT
 
 public:
-	 QDVDAuthor ();
-	~QDVDAuthor ();
+	QDVDAuthor ( );
+	virtual ~QDVDAuthor ( );
 
 public slots:
 	virtual void fileNew      ( );
@@ -139,6 +139,7 @@ public:
 	void removeSourceFileEntry          ( SourceFileEntry * );  // called to remove the SourceFileEntry
 	void removedSourceEntry             ( SourceFileEntry * );  // called after entry has been removed from SourceToolBar
 	void updateSourceFileInfo           ( SourceFileInfo  * );
+	void editSourceFileInfo             ( SourceFileInfo  * );
 	void replaceSourceDisplayName    ( QString &, QString & );
 	bool isSourceEntryUsed                      ( QString & );
 	void addSound                           ( QStringList & );
