@@ -122,7 +122,7 @@ void MPlayerInfo::slotRetryQuery ( )
 
   // If we could not acquire the lock we should delete the current mutex and create a new one. 
   // Note: this could be crash prone ???
-  if ( bTryToLockFailed = true ) {
+  if ( bTryToLockFailed == true ) {
     debug_out ( " Hard Out !\n" );
     delete m_pMutex;
     m_pMutex = new QMutex ( TRUE );
