@@ -112,8 +112,9 @@ void CSlideDialog::slotExport()
 	if ( ! m_pCheckBackground->isChecked () )
 		m_Slideshow.background = QString ("");
 	if (m_pCheckFilter->isChecked())	{
-		CXmlSlideshow theSlideshow = createFilterSlideshow ();	// Here we insert additionally somefilters and save it.
-		theSlideshow.writeXml(qsExportSlideshow);
+		CXmlSlideshow theSlideshow;
+		createFilterSlideshow ( &theSlideshow );	// Here we insert additionally somefilters and save it.
+		theSlideshow.writeXml ( qsExportSlideshow );
 	}
 	else
 		m_Slideshow.writeXml (qsExportSlideshow);
@@ -212,8 +213,8 @@ void CSlideDialog::slotOk()
 	CXmlSlideshow execSlideshow;
 	previewImage (m_pListTable->currentItem());
 	m_Slideshow.delay = m_pEditDelay->text().toInt();
-	if (m_pCheckFilter->isChecked())
-		execSlideshow = createFilterSlideshow ();	// Here we insert additionally somefilters and save it.
+	if ( m_pCheckFilter->isChecked ( ) )
+		createFilterSlideshow  ( &execSlideshow );	// Here we insert additionally somefilters and save it.
 	else
 		execSlideshow = m_Slideshow;
 
@@ -264,18 +265,21 @@ void CSlideDialog::slotApplyFilter()
 	DialogFilter *pDialog = new DialogFilter (this);
 
 	m_Slideshow.delay = m_pEditDelay->text().toInt();
-	if (m_pCheckFilter->isChecked())	{
+	if ( m_pCheckFilter->isChecked ( ) )	{
+		CXmlSlideshow theSlideshow;
 		m_Slideshow.filter_delay = m_pEditFilterDelay->text().toInt();
-		m_Slideshow = createFilterSlideshow();
+		createFilterSlideshow ( &theSlideshow );
+		m_Slideshow = theSlideshow;
 	}
 	else
 		m_Slideshow.filter_delay = 0;
 
-	pDialog->setImages(&m_Slideshow);
-	pDialog->show();
+	m_pPreview->resetImage ( );
+	pDialog->setImages ( &m_Slideshow );
+	pDialog->show ( );
 }
 
-void CSlideDialog::slotFilterToggled( bool bToggled)
+void CSlideDialog::slotFilterToggled ( bool bToggled )
 {
 	// In case we have already loaded a slideshow with some filters, we don't want to destroy any information.
 	if ((m_Slideshow.countFilter() > 0)	&& (bToggled) ){
@@ -390,41 +394,39 @@ void CSlideDialog::previewImage(int iItem)
   m_pPreview->setImage (pImg);
 }
 
-CXmlSlideshow &CSlideDialog::createFilterSlideshow ()
+void CSlideDialog::createFilterSlideshow ( CXmlSlideshow *pSlideshow )
 {
-	static CXmlSlideshow theSlideshow;
-	theSlideshow.clear();
+	pSlideshow->clear ( );
 	CXmlSlideshow::filter_struct	*pFilter;
 	CXmlSlideshow::time_object	*pOrigImage;
 	CXmlSlideshow::time_object	*pNewImage;
-	theSlideshow.filter_delay   = m_pEditFilterDelay->text().toInt();
-	theSlideshow.slideshow_name = m_Slideshow.slideshow_name;
-	theSlideshow.background     = m_Slideshow.background;
-	theSlideshow.delay          = m_Slideshow.delay;
-	theSlideshow.audio_list     = m_Slideshow.audio_list;
-	theSlideshow.xres           = m_Slideshow.xres;
-	theSlideshow.yres           = m_Slideshow.yres;
+	pSlideshow->filter_delay   = m_pEditFilterDelay->text().toInt();
+	pSlideshow->slideshow_name = m_Slideshow.slideshow_name;
+	pSlideshow->background     = m_Slideshow.background;
+	pSlideshow->delay          = m_Slideshow.delay;
+	pSlideshow->audio_list     = m_Slideshow.audio_list;
+	pSlideshow->xres           = m_Slideshow.xres;
+	pSlideshow->yres           = m_Slideshow.yres;
 	
-	pFilter = theSlideshow.addFilter();
-	pFilter->name = QString ("fadein");
+	pFilter = pSlideshow->addFilter  ( );
+	pFilter->name = QString ( "fadein" );
 	uint t, iImgCount;
-	iImgCount = m_Slideshow.countImg();
-	for (t=0;t<iImgCount;t++)	{
-		pNewImage  = (CXmlSlideshow::time_object *)theSlideshow.addImg();
-		pOrigImage = (CXmlSlideshow::time_object *)m_Slideshow.getImg(t);
+	iImgCount = m_Slideshow.countImg ( );
+	for ( t=0; t<iImgCount; t++ )	{
+		pNewImage  = (CXmlSlideshow::time_object *)pSlideshow->addImg  ( );
+		pOrigImage = (CXmlSlideshow::time_object *)m_Slideshow.getImg ( t );
 		*pNewImage = *pOrigImage;
 		if (t < iImgCount-1)	{
 			// The last filter ought to be a fadeout filter.
-			pFilter = theSlideshow.addFilter();
+			pFilter = pSlideshow->addFilter ( );
 			pFilter->name = QString ("crossfade");
 		}
 	}
-	pFilter = theSlideshow.addFilter();
-	pFilter->name = QString ("fadeout");
+	pFilter = pSlideshow->addFilter ( );
+	pFilter->name = QString ( "fadeout" );
 	
 	// And finally we write the structure out to the HD.
 	//	theSlideshow.writeXml (m_qsSlideshowFileName);
-	return theSlideshow;
 }
 
 void CSlideDialog::slotDelete()
