@@ -18,9 +18,11 @@
 #include <qpopupmenu.h>
 #include <qpainter.h>
 #include <qcursor.h>
+#include <qfileinfo.h>
 
 #include "imagepreview.h"
 #include "dialogimage.h"
+#include "modifiers2.h"
 
 ImagePreview::ImagePreview (QWidget *pParent, const char * name, WFlags f )
 	: QLabel (pParent, name, f) // |WRepaintNoErase)
@@ -30,6 +32,7 @@ ImagePreview::ImagePreview (QWidget *pParent, const char * name, WFlags f )
 	m_bFastPreview       = false; 
 	m_pImage             = NULL;
 	m_bActiveCursor      = false;
+	m_bActiveZoom        = false;
 	m_bNeedToAdjustColor = false;
 	m_bShowBackground    = false;
 	m_iOriginalWidth     = -1;
@@ -141,6 +144,7 @@ void ImagePreview::setImage (CXmlSlideshow::img_struct *pImg)
   m_pImage = pImg;
   setModifier ( );	// get the additional infos for this image
   preloadImage( );
+  adjustColor ( );
   centerImage ( );
   
   if ( ! pImg->src.isEmpty ( ) )
@@ -154,10 +158,18 @@ CXmlSlideshow::img_struct *ImagePreview::getImage()
 
 void ImagePreview::mousePressEvent (QMouseEvent *pEvent)
 {
-	if (pEvent->button () == LeftButton)	{
-		m_currentMousePos = pEvent->pos();
-		m_bActiveCursor = true;
-		setFastPreview(true);
+	if ( ( pEvent->button  ( ) == MidButton  ) || // If the midle button was pressed
+	     ( ( pEvent->button  ( ) == RightButton ) && ( m_bActiveCursor ) ) )  { // or first the left and second the right button ...
+		m_currentMousePos = pEvent->pos ( );
+		m_bActiveCursor   = false;
+		m_bActiveZoom     = true;
+		setFastPreview    ( true );
+		return;
+	}
+	else if ( pEvent->button ( ) == LeftButton )  {
+		m_currentMousePos = pEvent->pos  ( );
+		m_bActiveCursor   = true;
+		setFastPreview    ( true );
 		return;
 	}
 	if (m_pImage == NULL)
@@ -175,24 +187,30 @@ void ImagePreview::mousePressEvent (QMouseEvent *pEvent)
 void ImagePreview::mouseReleaseEvent (QMouseEvent *)
 {
 	m_bActiveCursor = false;
-	setFastPreview(false);
-	refreshPreview();
+	m_bActiveZoom   = false;
+	setFastPreview  ( false );
+	refreshPreview  ( );
 }
 
 void ImagePreview::mouseMoveEvent (QMouseEvent *pEvent)
 {
 	static bool bActive = false;
-	if (bActive)
+	if ( bActive )
 		return;
 	// this one we move the object regardless of the cursor beeing in or out.
-	if (m_bActiveCursor)	{
-		bActive = true;
+	bActive = true;
+	if ( m_bActiveZoom )	{
+		m_manipulator.fZoom -= (float)( pEvent->pos ( ).y ( ) - m_currentMousePos.y ( ) ) / height ( );
+		m_currentMousePos = pEvent->pos ( );
+		refreshPreview ( );
+	}
+	else if (m_bActiveCursor)	{
 		m_manipulator.fStartX += (float)(pEvent->pos().x() - m_currentMousePos.x())/width ();
 		m_manipulator.fStartY += (float)(pEvent->pos().y() - m_currentMousePos.y())/height();
-		m_currentMousePos = pEvent->pos();
-		refreshPreview();
-		bActive = false;
+		m_currentMousePos = pEvent->pos ( );
+		refreshPreview ( );
 	}
+	bActive = false;
 }
 
 void ImagePreview::mouseDoubleClickEvent (QMouseEvent *)
@@ -355,80 +373,12 @@ void ImagePreview::refreshPreview ()
 	}
 	setPixmap (background);
 }
-/*
-			QImage theImage = pixmap().convertToImage();
-			// Okay if the rotation is any angle, then we get black background even with background image enabled.
-			// Here we copy only those pixel over, which are part of the rotated image.
-*/
-/*
-Without transparency ...
-void ImagePreview::refreshPreview ()
-{
-	if (m_imageColored.isNull())
-		return;
-	if (m_bFastPreview)	{
-		update();
-		return;
-	}
-	if (m_background.isNull())
-		return;
 
-	int iTargetStartX, iTargetStartY, iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight;
-	QRect startRect, boundingRect;
-	float fZoom = m_fZoom * m_fStartZoom;
-	QWMatrix matrix;
-	QPixmap background;
-	QImage theImage;
-
-	if (m_iTransformationMode == 1)
-		matrix.setTransformationMode(QWMatrix::Areas);
-	matrix.translate (m_iStartX+(int)((float)m_image.width()/2.0*fZoom), m_iStartY+(int)((float)m_image.height()/2.0*fZoom));
-//	matrix.translate (m_iStartX, m_iStartY);
-	matrix.scale (fZoom, fZoom);
-	matrix.rotate(m_pImage->rotate);
-	matrix.shear (m_fShearX, m_fShearY);
-
-	// First we obtain a background to write to ...
-	background.convertFromImage(m_background);
-	// Now we twist and twitch the actual interesting image ...
-	// Note: we only need a QImage because we need to get access to the pixel, which we can't with a Pixmap.
-	theImage = m_imageColored.xForm ( matrix );
-
-	// We need the bounding Rect for copiing purposes, so first create the original rectangle
-	startRect = QRect((int)-(m_image.width()/ 2.0), (int)-(m_image.height()/2.0), m_image.width(), m_image.height());
-	// and then put it through the matrix transformation ...
-	boundingRect = matrix.mapRect(startRect);
-
-	int x, y;
-	QRgb thePixel;
-	QPainter thePainter (&background);
-	iSourceHeight = theImage.height();
-	iSourceWidth  = theImage.width ();
-	iSourceStartX = 0;
-	iSourceStartY = 0;
-	iTargetStartX = boundingRect.x();
-	iTargetStartY = boundingRect.y();
-
-	// Okay if the rotation is any angle, then we get black background even with background image enabled.
-	// Here we copy only those pixel over, which are part of the rotated image.
-	for (y=0; y < iSourceHeight; y++)	{
-		for (x=0; x < iSourceWidth; x++)	{
-			thePixel = theImage.pixel(x+iSourceStartX, y+iSourceStartY);
-			thePixel &= 0x00ffffff;	// filter out the transparency part
-			if (thePixel != 0x000000)	{
-				thePainter.setPen (QColor (thePixel));
-				thePainter.drawPoint(x+iTargetStartX, y+iTargetStartY);
-			}
-		}
-	}
-	setPixmap (background);
-}
-*/
 void ImagePreview::adjustColor()
 {
 	// m_image is the input,
 	// m_imageColored is the output ...
-	int iRed, iGreen, iBlue;
+	unsigned char iRed, iGreen, iBlue;
 	int x, y;
 	bool bLighter = true;
 	float fAdjust;
@@ -448,42 +398,48 @@ void ImagePreview::adjustColor()
 		bLighter = false;
 		fAdjust = 100 + m_manipulator.fBrightness * -300;
 	}
-	for (y=0;y<m_image.height();y++)	{
-		for (x=0;x<m_image.width();x++)	{
-			thePix = m_image.pixel(x, y);
-			iRed = (int)((float)qRed(thePix) * m_manipulator.fRed);
-			iBlue = (int)((float)qBlue(thePix) * m_manipulator.fBlue);
-			iGreen = (int)((float)qGreen(thePix) * m_manipulator.fGreen);
+	for ( y=0; y<m_image.height ( ); y++ )	{
+		for ( x=0; x<m_image.width ( ); x++ )	{
+			thePix = m_image.pixel ( x, y );
+			iRed   = (unsigned char)( (float)qRed  (thePix) * m_manipulator.fRed   );
+			iBlue  = (unsigned char)( (float)qBlue (thePix) * m_manipulator.fBlue  );
+			iGreen = (unsigned char)( (float)qGreen(thePix) * m_manipulator.fGreen );
 
-			theColor = QColor (iRed, iGreen, iBlue);
+			theColor = QColor ( iRed, iGreen, iBlue );
 			if (bLighter)
-				theColor = theColor.light ((int)fAdjust);
+				theColor = theColor.light ( (int)fAdjust );
 			else
-				theColor = theColor.dark ((int)fAdjust);
-			// This test is to mask out the transparency color (0, 0, 0)
-			if (theColor == QColor (0,0,0))
-				theColor = QColor (0,0,1);
-			m_imageColored.setPixel (x, y, theColor.rgb());
+				theColor = theColor.dark  ( (int)fAdjust );
+			// This test is to mask out the transparency color ( 0, 0, 0 )
+			if ( theColor == QColor ( 0, 0, 0 ) )
+				theColor = QColor  ( 0, 0, 1 );
+			m_imageColored.setPixel ( x, y, theColor.rgb ( ) );
 		}
 	}
 	m_bNeedToAdjustColor = false;
 }
 
-void ImagePreview::centerImage ()
+void ImagePreview::centerImage ( )
 {
-	if (m_image.isNull())
+	if ( m_image.isNull ( ) )
 		return;
-	if ( (m_manipulator.fStartX != 0.0) || (m_manipulator.fStartY >= 0.0) )
+
+	if ( ( m_manipulator.fStartX != 0.0f ) || ( m_manipulator.fStartY != 0.0f ) )
 		return;
+
 	m_manipulator.fStartX = ((width () - m_image.width ()) / 2.0 )/width ();
 	m_manipulator.fStartY = ((height() - m_image.height()) / 2.0 )/height();
 }
 
-void ImagePreview::preloadImage ()
+void ImagePreview::preloadImage ( )
 {
-	if (m_pImage->src.isEmpty())
-		return;
-	m_image = QImage (m_pImage->src);
+	QFileInfo fileInfo ( m_pImage->src ); 
+	if ( ( m_pImage->src.isEmpty ( ) ) || 
+	     ( ! fileInfo.exists     ( ) ) )  {
+		m_image = QImage::fromMimeSource ("error.jpg");
+	}
+	else
+		m_image = QImage  ( m_pImage->src );
 	m_iOriginalWidth  = m_image.width  ( );
 	m_iOriginalHeight = m_image.height ( );
 //	int iWidth  = m_image.width ();
@@ -495,7 +451,7 @@ void ImagePreview::preloadImage ()
 	// And here we create the right m_coloredImage;
 //	m_manipulator.fZoom = (float)((float) m_image.width () / iWidth);
 //	m_fStartZoom = (float)((float) m_image.width () / iWidth);
-	adjustColor ();
+//	adjustColor ();
 }
 
 void ImagePreview::slotRotate90 ()
