@@ -58,7 +58,6 @@
 
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
-#include "qplayer/sourcefiledialog.h"
 
 #define SOURCE_FILE_ENTRY_ID   0
 #define SOURCE_FILE_ENTRY_NAME 1
@@ -278,11 +277,12 @@ void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPo
     else {
       // Not a sound source
       if (bShow)
-	pMenu->insertItem ( tr ("Play"),               this, SLOT(slotPlayMovie     ( ) ) );
-      pMenu->insertItem   ( tr ("Properties ..."),     this, SLOT(slotEditMovie     ( ) ) );
+	pMenu->insertItem ( tr ("&Play"),               this, SLOT(slotPlayMovie     ( ) ) );
+      pMenu->insertItem   ( tr ("P&roperties ..."),     this, SLOT(slotEditMovie     ( ) ) );
       if ( pSourceFileEntry && (pSourceFileEntry->listFileInfos.count() > 1) ) {
-	pMenu->insertItem ( tr ("Transcode All ..."),  this, SLOT(slotTranscodeAll  ( ) ) );
-	pMenu->insertItem ( tr ("All to titleset ..."),this, SLOT(slotAllToTitleset ( ) ) );
+	pMenu->insertItem ( tr ("&Transcode All ..."),  this, SLOT(slotTranscodeAll  ( ) ) );
+	pMenu->insertItem ( tr ("&Disable Transcode" ), this, SLOT(slotTranscodeNone ( ) ) );
+	pMenu->insertItem ( tr ("&All to titleset ..."),this, SLOT(slotAllToTitleset ( ) ) );
       }
       else if ( !pSourceFileEntry ) { // Here we handle if the user clicked on a SourceFileInfo
 	SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
@@ -446,6 +446,59 @@ void SourceToolBar::slotTranscodeAll()
   updateEntryHeader ( pSourceFileEntry );
 }
 
+
+void SourceToolBar::slotTranscodeNone ( )
+{
+  uint t;
+  //QFileInfo fileInfo;
+  bool bFound = false;
+  // Called when the user clicks on the SourceFileEntry - header.
+  // This function will transcode all associated SourceFiles into the same format.
+  SourceFileEntry *pSourceFileEntry = NULL;
+  SourceFileInfo  *pSourceFileInfo  = NULL;
+  QListViewItem   *pItem = m_pListViewAllSources->currentItem ( );
+
+  if ( ! pItem ) 
+    return;
+  for  ( t=0; t<m_listSourceFileEntries.count ( ); t++ )  {
+    if ( pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName )  {
+      pSourceFileEntry = m_listSourceFileEntries[t];
+      break;
+    }
+  }
+  
+  if ( ! pSourceFileEntry )
+    return; // Could not find the currently selected SourceFileEntry
+
+  for ( t=0; t<pSourceFileEntry->listFileInfos.count ( ); t++ )  {
+    pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+    if ( ! pSourceFileInfo ) // error
+      continue;
+    if ( pSourceFileInfo->pTranscodeInterface ) {
+      bFound = true;
+      break;
+    }
+  }
+
+  if ( bFound ) {
+    if ( MessageBox::question ( NULL, tr ( "Warnig disabling all transcoding." ), 
+	  tr ( "Are you sure you want to disable transcoding for this source entry ?" ),
+	  QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
+      return;
+  }
+  
+  for ( t=0; t<pSourceFileEntry->listFileInfos.count ( ); t++ )  {
+    pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+    if ( ! pSourceFileInfo ) // error
+      continue;
+    if ( pSourceFileInfo->pTranscodeInterface ) {
+      delete pSourceFileInfo->pTranscodeInterface;
+      pSourceFileInfo->pTranscodeInterface = NULL;
+    }
+  }
+  refreshToolBarEntries ( );
+}
+
 void SourceToolBar::slotToNewSubmenu ( )
 {
   // Here we add a copy of the current menu to the project and insert the selected Source.
@@ -1000,13 +1053,13 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	// Before we insert it we should remove all previous entries so that we hold only one entry for one sound file
 	//	removeEntry (qsFileName);
 
-	MediaInfo *pMediaInfo = MediaCreator::createInfo (getMediaEngine());
+	MediaInfo *pMediaInfo   = MediaCreator::createInfo (getMediaEngine());
 	QColor statusColor (COLOR_SOUND_FILES_OK);
-	SourceFileInfo  *pInfo;
+	SourceFileInfo  *pInfo  = NULL;
 	SourceFileEntry *pEntry = new SourceFileEntry;
-	pEntry->bSoundSource = true;
+	pEntry->bSoundSource    = true;
 	pEntry->arrayAudioEntries[0].iAudioNumber = -1; // Language settings etc is handled on the menu level for Audio tracks
-	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
+	pEntry->sizeThumbnail   = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
 	for (t=0;t<listSoundNames.count();t++)	{
 		pMediaInfo->setFileName (listSoundNames[t]);
 		// Lets create a new SoourceFileEntry for this sound file ...
@@ -1047,7 +1100,8 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 
 	// And further on to the m_pListViewVideoSources ...
-	new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsAudioFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
+	if ( pInfo )
+		new QListViewItem ( m_pSourceWidget->m_pListViewAudioSources, pInfo->qsAudioFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName );
 	delete pMediaInfo;
 }
 
@@ -1067,69 +1121,39 @@ void SourceToolBar::slotAddSlideshow()
   // newly generated slideshow. This is then done SourceToolBar::slotAddSlideshow(QString);
 }
 
-void SourceToolBar::slotEditMovie()
+void SourceToolBar::slotEditMovie ( )
 {
-	// Here we open the MovieDialog.
-	ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
-	if (!pItem)
-		return;
-	SourceFileInfo *pSourceFileInfo = pItem->sourceFileInfo();
-	if (pSourceFileInfo)	{
-		DialogMovie *pDialog = new DialogMovie (this);
-		pDialog->initMe (pSourceFileInfo, getMediaEngine ( ), m_pDVDAuthor );
-		connect ( pDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
-		if (pDialog->exec () == QDialog::Accepted) {
-			*pSourceFileInfo = *pDialog->sourceFileInfo();
-			// next is to update the entries if neccesary ...
-			updateListViewItem ( pSourceFileInfo );
-			m_pDVDAuthor->slotCalculateSize ( );
-		}
-		disconnect ( pDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
-		delete pDialog;
-		return;
-	}
-	
-	QStringList listFileTypes;
-	SourceFileEntry *pSourceFileEntry = getCurrentSourceFileEntry ();
-	if ( ! pSourceFileEntry )
-	  return;
-	if ( pSourceFileEntry->bSoundSource )
-	  return;
+  // Here we open the MovieDialog.
+  ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
+  if ( ! pItem )
+    return;
+  SourceFileInfo *pInfo = pItem->sourceFileInfo ( );
+  if ( ! pInfo ) {
+    SourceFileEntry *pEntry =  pItem->sourceFileEntry ( );
+    if ( ( ! pEntry ) || ( pEntry->listFileInfos.count ( ) < 1 ) )
+      return;
+    pInfo = pEntry->listFileInfos[0];
+  }
+  if ( pInfo )
+    editSourceFileInfo ( pInfo );
+}
 
-//	QListViewItem *pItem = m_pListViewAllSources->currentItem ();
-//	int iCurrent = (int)( (float)pItem->itemPos() / (float)pItem->height());
-	int iCurrent = 0;
-	for (iCurrent=0;iCurrent<(int)m_listSourceFileEntries.count();iCurrent++)
-		if (m_listSourceFileEntries[iCurrent] == pSourceFileEntry)
-			break;
+void SourceToolBar::editSourceFileInfo ( SourceFileInfo  *pSourceFileInfo )
+{
+  if ( ! pSourceFileInfo )
+    return;
 
-	QString qsOriginalDisplayName = pSourceFileEntry->qsDisplayName;
-	listFileTypes.append (tr ("Movie/Image Files (+Movies+ *.bmp *.png *.jpg *.gif *.xbm)"));
-	listFileTypes.append (tr ("Movie Files (+Movies+)"));
-	listFileTypes.append (tr ("Image Files (*.bmp *.png *.jpg *.gif *.xbm)"));
-	listFileTypes.append (tr ("All Files (*)"));
-
-	// Here we try to find out if we have a movie or a sound ...
-	int iWhichTab = SOURCE_FILE_TAB;
-//	if (	(iCurrent < (int)m_listSourceFileEntries.count ()) &&
-//			(m_listSourceFileEntries[iCurrent]->bSoundSource) )
-	if (pSourceFileEntry->bSoundSource)
-		iWhichTab = SOUND_OPTIONS_TAB;
-
-
-	SourceFileDialog *pDialog = new SourceFileDialog(getMediaEngine (), this, iWhichTab);
-	pDialog->setFileTypes (listFileTypes);
-	pDialog->setSourceFileEntries(m_listSourceFileEntries,  iCurrent);
-
-	int iReturn = pDialog->exec();
-	if (iReturn == QDialog::Rejected)
-		return;
-	refreshToolBarEntries();
-	// Here we check if the DisplayName has been changed. Note that the pointer has not changed, only the values.
-	if ( (qsOriginalDisplayName != pSourceFileEntry->qsDisplayName) && (m_pDVDAuthor) )
-			m_pDVDAuthor->replaceSourceDisplayName(qsOriginalDisplayName, pSourceFileEntry->qsDisplayName);
-
-	delete pDialog;
+  DialogMovie *pDialog = new DialogMovie ( this );
+  pDialog->initMe ( pSourceFileInfo, getMediaEngine ( ), m_pDVDAuthor );
+  connect ( pDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
+  if ( pDialog->exec ( ) == QDialog::Accepted )  {
+    *pSourceFileInfo  = *pDialog->sourceFileInfo ( );
+    // next is to update the entries if neccesary ...
+    updateListViewItem ( pSourceFileInfo );
+    m_pDVDAuthor->slotCalculateSize ( );
+  }
+  disconnect ( pDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
+  delete pDialog;
 }
 
 void SourceToolBar::slotEditAudio ( )
