@@ -25,30 +25,36 @@
 #include "textobject.h"	// derived from menuobject
 #include "structuretoolbar.h"
 
-TextObject::TextObject (QWidget *pParent)
-	: MenuObject (pParent)
+TextObject::TextObject ( QWidget *pParent )
+	: MenuObject   ( pParent )
 {
 	m_qsObjectType    = QString ( TEXT_OBJECT );
 	m_colorBackground = Rgba    ( TRANSPARENT_COLOR );   // indicate the transparent color.
 	m_iStyleStrategy  = QFont::PreferAntialias;
 	m_pContextMenu    = NULL;
+	m_bAllowWordBreak = true;
 }
 
-TextObject::~TextObject ()
+TextObject::~TextObject ( )
 {
-	if (m_pContextMenu)
-		delete m_pContextMenu;
-	m_pContextMenu = NULL;
+  if ( m_pContextMenu )
+    delete m_pContextMenu;
+  m_pContextMenu = NULL;
 }
 
-void TextObject::setFont (QFont &theFont)
+void TextObject::setFont ( QFont &theFont )
 {
-	m_Font = theFont;
+  m_Font = theFont;
 }
 
 QFont &TextObject::getFont ()
 {
-	return m_Font;
+  return m_Font;
+}
+
+void TextObject::setWordBreak ( bool bBreak )
+{
+  m_bAllowWordBreak = bBreak;
 }
 
 void TextObject::setText (QString &theText)
@@ -121,196 +127,199 @@ Rgba &TextObject::getBackgroundColor ()
 
 void TextObject::drawSemiTransparent (QPainter *pPainter)
 {
-//printf ( "%s::%s : %d  \n", __FILE__, __FUNCTION__, __LINE__ );
-        if ( m_pShadow && ! m_bDrawRect )
-	     m_pShadow->drawContents ( pPainter );
-	QWMatrix theMatrix;
-	QRect dummyRect, theRect;
-	int iFlags, x, y;
-	int iSourceHeight, iSourceWidth, iSourceStartX, iSourceStartY, iTargetStartX, iTargetStartY;
-	Rgba sourceColor, targetColor, theColor;
-	QRgb sourcePixel, targetPixel;
-	QImage sourceImg, targetImg;
-	float fTargetTrans, fSourceTrans;
+  //printf ( "%s::%s : %d  \n", __FILE__, __FUNCTION__, __LINE__ );
+  if ( m_pShadow && ! m_bDrawRect )
+       m_pShadow->drawContents ( pPainter );
+  QWMatrix theMatrix;
+  QRect dummyRect, theRect;
+  int iFlags, x, y;
+  int iSourceHeight, iSourceWidth, iSourceStartX, iSourceStartY, iTargetStartX, iTargetStartY;
+  Rgba sourceColor, targetColor, theColor;
+  QRgb sourcePixel, targetPixel;
+  QImage sourceImg, targetImg;
+  float fTargetTrans, fSourceTrans;
 
-	// init variables ...
-	fTargetTrans = 1.0 - modifiers()->fTransparency;
-	fSourceTrans = modifiers()->fTransparency;
+  // init variables ...
+  fTargetTrans = 1.0 - modifiers()->fTransparency;
+  fSourceTrans = modifiers()->fTransparency;
 
-	QPen thePen ( m_colorForeground.color ( ), 2, Qt::DashDotLine );
-	// Here we define the cenetered rect.
-	theRect = QRect((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+  QPen thePen ( m_colorForeground.color ( ), 2, Qt::DashDotLine );
+  // Here we define the cenetered rect.
+  theRect = QRect((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
 
-	// First we translate to the center of the rect.
-	theMatrix.translate (
-		(double)rect().x() + (int)(rect().width () / 2.0), 
-		(double)rect().y() + (int)(rect().height() / 2.0));
-	//. then we apply the other modifications ...
-	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.rotate (modifiers()->fRotate);
-	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
-	// Here we get the rect that encompasses the button for this object.
-	m_boundingRect = theMatrix.mapRect(theRect);
-	// And for the source we need to set the right matrix.
-	theMatrix.reset  ();
-	theMatrix.translate ((double)m_boundingRect.width()/2.0, (double)m_boundingRect.height()/2.0);
-	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.rotate (modifiers()->fRotate);
-	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
+  // First we translate to the center of the rect.
+  theMatrix.translate ( (double)rect().x() + (int)(rect().width () / 2.0), 
+		        (double)rect().y() + (int)(rect().height() / 2.0) );
+  //. then we apply the other modifications ...
+  theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
+  theMatrix.rotate (modifiers()->fRotate);
+  theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
+  // Here we get the rect that encompasses the button for this object.
+  m_boundingRect = theMatrix.mapRect(theRect);
+  // And for the source we need to set the right matrix.
+  theMatrix.reset  ();
+  theMatrix.translate ((double)m_boundingRect.width()/2.0, (double)m_boundingRect.height()/2.0);
+  theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
+  theMatrix.rotate (modifiers()->fRotate);
+  theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
+  
+  QPixmap thePixmap = QPixmap ( m_boundingRect.size ( ) );
+  if (thePixmap.isNull())
+    return;
 
-	QPixmap thePixmap = QPixmap ( m_boundingRect.size ( ) );
-	if (thePixmap.isNull())
-		return;
+  thePixmap.fill ( QColor ( TRANSPARENT_COLOR ) );
+  QPainter pmPainter (&thePixmap);
+  //  then we actually set the world matrix 
+  pmPainter.setWorldMatrix(theMatrix);
 
-	thePixmap.fill ( QColor ( TRANSPARENT_COLOR ) );
-	QPainter pmPainter (&thePixmap);
-	//  then we actually set the world matrix 
-	pmPainter.setWorldMatrix(theMatrix);
-
-	pmPainter.setPen   ( Qt::NoPen );
-	pmPainter.setBrush ( QBrush    ( m_colorBackground.color ( ) ) );
-	pmPainter.drawRect ( theRect   );
+  pmPainter.setPen   ( Qt::NoPen );
+  pmPainter.setBrush ( QBrush    ( m_colorBackground.color ( ) ) );
+  pmPainter.drawRect ( theRect   );
  
-	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
-	pmPainter.setFont(m_Font);
+  m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
+  pmPainter.setFont(m_Font);
 
-	// Okay, I abused a QPoint class to hold some other infos ... so what ???
-	iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
+  // Okay, I abused a QPoint class to hold some other infos ... so what ???
+  //iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
+  iFlags = Qt::DontClip|m_ptTextAlign.x ( )|m_ptTextAlign.y ( );
+  if ( m_bAllowWordBreak )
+    iFlags |= Qt::WordBreak;
+  
+  pmPainter.drawText(theRect, iFlags, m_qsText, -1, &dummyRect);
+  
+  // At this point we should have the text on a memory Bitmap object, and now 
+  // we should copy this over, bit for bit. 
+  iSourceHeight = thePixmap.height(); 
+  iSourceWidth  = thePixmap.width ();
+  iSourceStartX = 0;
+  iSourceStartY = 0;
+  iTargetStartX = pPainter->viewport().x() + m_boundingRect.x();
+  iTargetStartY = pPainter->viewport().y() + m_boundingRect.y();
+  
+  // First we need to create a Pixmap which holds the Target pixels
+  QPaintDevice *pPDPainter = pPainter->device();
+  if (pPDPainter == 0)
+    return;
 
-	pmPainter.drawText(theRect, iFlags, m_qsText, -1, &dummyRect);
-	
-	// At this point we should have the text on a memory Bitmap object, and now 
-	// we should copy this over, bit for bit. 
-	iSourceHeight = thePixmap.height(); 
-	iSourceWidth  = thePixmap.width ();
-	iSourceStartX = 0;
-	iSourceStartY = 0;
-	iTargetStartX = pPainter->viewport().x() + m_boundingRect.x();
-	iTargetStartY = pPainter->viewport().y() + m_boundingRect.y();
+  sourceImg = thePixmap.convertToImage();
 
-	// First we need to create a Pixmap which holds the Target pixels
-	QPaintDevice *pPDPainter = pPainter->device();
-	if (pPDPainter == 0)
-		return;
+  QPixmap *pPixmap = new QPixmap(iSourceWidth, iSourceHeight);
+  if ( ! pPixmap )
+    return;
+  bitBlt (pPixmap, 0, 0, pPainter->device(), 
+	  iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
+  // To get Pixel information we need a QImage however ...
+  targetImg = pPixmap->convertToImage();
+  delete pPixmap;
 
-	sourceImg = thePixmap.convertToImage();
-
-	QPixmap *pPixmap = new QPixmap(iSourceWidth, iSourceHeight);
-	if ( ! pPixmap )
-		return;
-	bitBlt (pPixmap, 0, 0, pPainter->device(), 
-		iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
-		// To get Pixel information we need a QImage however ...
-	targetImg = pPixmap->convertToImage();
-	delete pPixmap;
-
-	iTargetStartX -= pPainter->viewport().x();
-	iTargetStartY -= pPainter->viewport().y();
-	for (y=0; y < iSourceHeight; y++)	{
-		for (x=0; x < iSourceWidth; x++)	{
-			sourcePixel = sourceImg.pixel(x, y );	// calculate the mix of background and foreground.
-			sourcePixel &= 0x00ffffff;// filter out the transparency part of the color
-			if (sourcePixel != 0x00FFFFFF)	{	// And check if this is a pixel we 
-				targetPixel = targetImg.pixel(x, y);
-				targetPixel &= 0x00ffffff;	// filter out the transparency part of the color
-				targetColor = Rgba ( targetPixel );
-				sourceColor = Rgba ( sourcePixel );
-				theColor    = Rgba (
-					(int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
-					(int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
-					(int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
-				);
-				pPainter->setPen ( theColor.color ( ) );
-				pPainter->drawPoint(x+iTargetStartX, y+iTargetStartY);
-			}
-		}
-	}
+  iTargetStartX -= pPainter->viewport().x();
+  iTargetStartY -= pPainter->viewport().y();
+  for (y=0; y < iSourceHeight; y++)	{
+    for (x=0; x < iSourceWidth; x++)	{
+      sourcePixel = sourceImg.pixel(x, y );	// calculate the mix of background and foreground.
+      sourcePixel &= 0x00ffffff;// filter out the transparency part of the color
+      if (sourcePixel != 0x00FFFFFF)	{	// And check if this is a pixel we 
+	targetPixel = targetImg.pixel(x, y);
+	targetPixel &= 0x00ffffff;	// filter out the transparency part of the color
+	targetColor = Rgba ( targetPixel );
+	sourceColor = Rgba ( sourcePixel );
+	theColor    = Rgba ( (int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
+			     (int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
+			     (int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
+			     );
+	pPainter->setPen ( theColor.color ( ) );
+	pPainter->drawPoint(x+iTargetStartX, y+iTargetStartY);
+      }
+    }
+  }
 }
 
 void TextObject::drawContents (QPainter *painter)
 {
-	QWMatrix theMatrix;// = matrix();
-	// If we have a complete transparent text we should not draw at all.
-	if (modifiers()->fTransparency == 1.0)
-		return;
-	else if ( (modifiers()->fTransparency != 0.0) && ( ! m_bDrawRect) )
-		return drawSemiTransparent ( painter );
-
-        if ( m_pShadow && ! m_bDrawRect )
-	     m_pShadow->drawContents ( painter );
-	// Here we calculate the center point of gravity (rotation)
-	QPoint centerPos;
-	centerPos.setX (rect().x() + (int)(rect().width () / 2.0));
-	centerPos.setY (rect().y() + (int)(rect().height() / 2.0));
-	// Here we define the cenetered rect.
-	QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
-
-	// From the Qt documentation ...
-	// This transformation engine is a three-step pipeline
-	// The first step uses the world transformation matrix.
-	// The second step uses the window.
-	// The third step uses the viewport.
-
-	// First we translate to the appropriate location,
-	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
-
-	//. then we apply the other modifications ...
-	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.rotate (modifiers()->fRotate);
-	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
-	
-	QPen thePen ( m_colorForeground.color ( ), 2, Qt::DashDotLine);
-	painter->setPen ( thePen );
-	
-	// Here we get the rect that encompasses the button for this object.
-	m_boundingRect = theMatrix.mapRect(theRect);
-	if (m_bDrawRect) {
-	  drawActiveFrame ( painter );
-	  //painter->drawRect(m_boundingRect);
-	}
-	//  then we actually set the world matrix 
-	painter->setWorldMatrix(theMatrix);
-
-	// and continue to draw the contents ...
-	if ( m_colorBackground.alpha ( ) > 0 )  {
-		// No frame wanted, we take care of that ourself if requested ...
-		painter->setPen   ( Qt::NoPen );
-		painter->setBrush ( QBrush ( m_colorBackground.color ( ) ) );
-		painter->drawRect ( theRect );
-		// and re-set the PEN.
-		painter->setPen   ( thePen );
-	}
-	else
-		painter->setBrush ( Qt::NoBrush );
-
-	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
-	painter->setFont(m_Font);
-	QRect boundingRect;
-	bool bUpdateAgain = false;
-	// Okay, I abused a QPoint class to hold some other infos ... so what ???
-	int iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
-	if (m_bDrawRect)
-		painter->drawRect(theRect);
-
-	painter->drawText(theRect, iFlags, m_qsText, -1, &boundingRect);
-	// Here we expand the rectangle if needs be, and update again, to re-draw.
-	if (m_rect.width() < boundingRect.width())	{
-		m_rect.setWidth  (boundingRect.width());
-		bUpdateAgain = true;
-	}
-	if (m_rect.height() < boundingRect.height())	{
-		m_rect.setHeight (boundingRect.height());
-		bUpdateAgain = true;
-	}
-
-	if ( bUpdateAgain ) {
-	  m_pParent->update ( );
-	  updateShadow      ( );
-	}
-
-	// Here we re-set the world matrix and translate the newly drawn ... thing ...
-	theMatrix.reset();
-	painter->setWorldMatrix(theMatrix);
+  QWMatrix theMatrix;
+  // If we have a complete transparent text we should not draw at all.
+  if ( modifiers ( )->fTransparency == 1.0 )
+    return;
+  else if ( (modifiers ( )->fTransparency != 0.0 ) && ( ! m_bDrawRect ) )
+    return drawSemiTransparent ( painter );
+  
+  if ( m_pShadow && ! m_bDrawRect )
+    m_pShadow->drawContents ( painter );
+  // Here we calculate the center point of gravity (rotation)
+  QPoint centerPos;
+  centerPos.setX (rect().x() + (int)(rect().width () / 2.0));
+  centerPos.setY (rect().y() + (int)(rect().height() / 2.0));
+  // Here we define the cenetered rect.
+  QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+  
+  // From the Qt documentation ...
+  // This transformation engine is a three-step pipeline
+  // The first step uses the world transformation matrix.
+  // The second step uses the window.
+  // The third step uses the viewport.
+  
+  // First we translate to the appropriate location,
+  theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );
+  
+  //. then we apply the other modifications ...
+  theMatrix.scale  ( modifiers ( )->fScaleX, modifiers ( )->fScaleY );
+  theMatrix.rotate ( modifiers ( )->fRotate);
+  theMatrix.shear  ( modifiers ( )->fShearX, modifiers ( )->fShearY );
+  
+  QPen thePen ( m_colorForeground.color ( ), 2, Qt::DashDotLine);
+  painter->setPen ( thePen );
+  
+  // Here we get the rect that encompasses the button for this object.
+  m_boundingRect = theMatrix.mapRect ( theRect );
+  if ( m_bDrawRect )
+    drawActiveFrame ( painter );
+  
+  //  then we actually set the world matrix 
+  painter->setWorldMatrix ( theMatrix );
+  
+  // and continue to draw the contents ...
+  if ( m_colorBackground.alpha ( ) > 0 )  {
+    // No frame wanted, we take care of that ourself if requested ...
+    painter->setPen   ( Qt::NoPen );
+    painter->setBrush ( QBrush ( m_colorBackground.color ( ) ) );
+    painter->drawRect ( theRect );
+    // and re-set the PEN.
+    painter->setPen   ( thePen );
+  }
+  else
+    painter->setBrush ( Qt::NoBrush );
+  
+  m_Font.setStyleStrategy ( (QFont::StyleStrategy)m_iStyleStrategy );
+  painter->setFont ( m_Font );
+  QRect boundingRect;
+  bool  bUpdateAgain = false;
+  // Okay, I abused a QPoint class to hold some other infos ... so what ???
+  int iFlags = Qt::DontClip|m_ptTextAlign.x ( )|m_ptTextAlign.y ( );
+  if ( m_bAllowWordBreak )
+    iFlags |= Qt::WordBreak;
+  
+  if ( m_bDrawRect )
+    painter->drawRect ( theRect );
+  
+  painter->drawText ( theRect, iFlags, m_qsText, -1, &boundingRect );
+  // Here we expand the rectangle if needs be, and update again, to re-draw.
+  if ( m_rect.width ( ) < boundingRect.width ( ) )  {
+    m_rect.setWidth ( boundingRect.width ( ) );
+    bUpdateAgain = true;
+  }
+  if ( m_rect.height ( ) < boundingRect.height ( ) )  {
+    m_rect.setHeight ( boundingRect.height ( ) );
+    bUpdateAgain = true;
+  }
+  
+  // Here we re-set the world matrix and translate the newly drawn ... thing ...
+  theMatrix.reset ( );
+  painter->setWorldMatrix ( theMatrix );
+  
+  if ( bUpdateAgain ) {
+    m_pParent->update ( );
+    updateShadow      ( );
+  }
 }
 
 void TextObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
@@ -503,53 +512,55 @@ bool TextObject::mouseReleaseEvent (QMouseEvent *)
 
 bool TextObject::mouseDoubleClickEvent (QMouseEvent *)
 {
-	QFont theFont;
-	DialogTextFont fontDialog (m_pParent);
-	fontDialog.setFont (getFont());
-	fontDialog.setText (getText());
-	fontDialog.setTextAlign       ( getTextAlign       ( ) );
-	fontDialog.setBackgroundColor ( getBackgroundColor ( ) );
-	fontDialog.setForegroundColor ( getForegroundColor ( ) );
-	fontDialog.setTransparency    ( modifiers ( )->fTransparency);
-	fontDialog.setAnimation       ( animation ( ) );
-	fontDialog.setRect   ( rect ( ) );	// setRect (boundingRect());
-	if ( fontDialog.exec ( ) == QDialog::Rejected )
-	  return false;
+  QFont theFont;
+  DialogTextFont fontDialog ( m_pParent, this );
+	
+  if ( fontDialog.exec ( ) == QDialog::Rejected )
+    return false;
 
-	setFont(fontDialog.getFont());
-	QString theString = fontDialog.getText();
-	setText(theString);
-	setAnimation (fontDialog.getAnimation ());
-	if (fontDialog.getBackgroundColor() != getBackgroundColor())	{
-		// This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
-		// was changed (I.e. This Object is in one of those two frames).
-		// Otherwise the signal is ignored.
-		emit (signalMaskColorChanged(fontDialog.getBackgroundColor(), getBackgroundColor()));
-		// P.s. replaceColor (QColor, QColor) of all ButtonObjects will be called, inclusive this object)
-	}
-	setBackgroundColor (fontDialog.getBackgroundColor());
-	if (fontDialog.getForegroundColor() != getForegroundColor())	{
-		// This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
-		// was changed (I.e. This Object is in one of those two frames).
-		// Otherwise the signal is ignored.
-		emit (signalMaskColorChanged(fontDialog.getForegroundColor(), getForegroundColor()));
-		// P.s. replaceColor (QColor, QColor) of all ButtonObjects will be called, inclusive this object)
-	}
-	setForegroundColor (fontDialog.getForegroundColor());
-	modifiers()->fTransparency = fontDialog.getTransparency();
-	setTextAlign(fontDialog.getTextAlign());
-	if (fontDialog.getFit())	{
-		rect().setWidth (1);
-		rect().setHeight(1);
-	}
-	else
-		setRect(fontDialog.getRect());
-
-	m_pParent->update ( );
-	updateShadow      ( );
-	emit (signalUpdatePixmap    ( ) );
-	emit (signalUpdateStructure ( ) );
-	return false;
+  setFont(fontDialog.getFont());
+  QString theString = fontDialog.getText();
+  setText(theString);
+  setAnimation (fontDialog.getAnimation ());
+  if (fontDialog.getBackgroundColor() != getBackgroundColor())	{
+    // This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
+    // was changed (I.e. This Object is in one of those two frames).
+    // Otherwise the signal is ignored.
+    emit (signalMaskColorChanged(fontDialog.getBackgroundColor(), getBackgroundColor()));
+    // P.s. replaceColor (QColor, QColor) of all ButtonObjects will be called, inclusive this object)
+  }
+  setBackgroundColor (fontDialog.getBackgroundColor());
+  if (fontDialog.getForegroundColor() != getForegroundColor())	{
+    // This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
+    // was changed (I.e. This Object is in one of those two frames).
+    // Otherwise the signal is ignored.
+    emit (signalMaskColorChanged(fontDialog.getForegroundColor(), getForegroundColor()));
+    // P.s. replaceColor (QColor, QColor) of all ButtonObjects will be called, inclusive this object)
+  }
+  setForegroundColor ( fontDialog.getForegroundColor ( ) );
+  modifiers ( )->fTransparency = fontDialog.getTransparency ( );
+  setTextAlign ( fontDialog.getTextAlign ( ) );
+  if ( fontDialog.getFit ( ) )  {
+    rect ( ).setWidth  ( 1 );
+    rect ( ).setHeight ( 1 );
+    setWordBreak   ( false );
+  }
+  else
+    setRect ( fontDialog.getRect ( ) );
+  
+  m_pParent->update ( );
+  
+  QRect orig = rect ( );
+  updateShadow      ( );
+  emit ( signalUpdatePixmap    ( ) );
+  
+  if ( rect ( ) != orig ) // if the rect has changed ...
+    emit ( signalUpdatePixmap  ( ) );
+  
+  emit ( signalUpdateStructure ( ) );
+  
+  setWordBreak ( true );
+  return false;
 }
 
 void TextObject::slotEdit ()
