@@ -375,7 +375,7 @@ QString Utils::iso639 (QString qsCode, bool bReverse, int iWhich )
 {
 	// This function will return the Country name of the found two-letter - code
 	// according to the iso639 standard (ftp://dkuug.dk/i18n/ISO_639)
-	char *arrayCountry [] = {"aa", "Afar", "ab", "Abkhazian", "af", "Afrikaans", 
+	char arrayCountry[278][36] = {"aa", "Afar", "ab", "Abkhazian", "af", "Afrikaans", 
 	"am", "Amharic", "ar", "Arabic", "as", "Assamese", "ay", "Aymara", "az", "Azerbaijani", 
 	"ba", "Bashkir", "be", "Byelorussian", "bg", "Bulgarian", "bh", "Bihari", "bi", "Bislama", 
 	"bn", "Bengali; Bangla", "bo", "Tibetan", "br", "Breton", "ca", "Catalan", "co", "Corsican", 
@@ -405,7 +405,7 @@ QString Utils::iso639 (QString qsCode, bool bReverse, int iWhich )
 	uint t, iCount;
 	int iReverse;
 	QString qsReturn;
-	iCount = (int)(sizeof (arrayCountry) / (sizeof (char *) * 2.0));
+	iCount = (int)(sizeof (arrayCountry) / (sizeof (char) * 36 * 2));
 	// Determines forward/backward looking up.
 	iReverse = 0;
 	if (bReverse)
@@ -452,9 +452,9 @@ QString Utils::getToolsDisplayName (QString qsExecutableName)
 	int t = getIndexFromToolName (qsExecutableName);
 	// All external Tools are defined in global.h
 	struct structTools { 
-		char *pExecutableName;
-		char *pDisplayName;
-		char *pDescription;
+		char pExecutableName[16];
+		char pDisplayName[16];
+		char pDescription[1024];
 	};
 	const structTools toolsArray[] = { EXTERNAL_TOOLS };
 
@@ -468,13 +468,12 @@ int Utils::getIndexFromToolName (QString qsExecutableName)
 	uint t, iNrOfTools;
 	// All external Tools are defined in global.h
 	struct structTools { 
-		char *pExecutableName;
-		char *pDisplayName;
-		char *pDescription;
+		char pExecutableName[16];
+		char pDisplayName[16];
+		char pDescription[1024];
 	};
 	const structTools toolsArray[] = { EXTERNAL_TOOLS };
-	iNrOfTools = sizeof (toolsArray) / ((sizeof (char *) * 3));
-
+	iNrOfTools = sizeof ( toolsArray ) / ( sizeof ( structTools ) );
 	for (t=0;t<iNrOfTools;t++)
 		if (qsExecutableName == QString (toolsArray[t].pExecutableName))
 			return t;
@@ -486,12 +485,12 @@ QString Utils::getToolByIndex (uint iIndex)
 	uint iNrOfTools;
 	// All external Tools are defined in global.h
 	struct structTools { 
-		char *pExecutableName;
-		char *pDisplayName;
-		char *pDescription;
+		char pExecutableName[16];
+		char pDisplayName[16];
+		char pDescription[1024];
 	};
 	const structTools toolsArray[] = { EXTERNAL_TOOLS };
-	iNrOfTools = sizeof (toolsArray) / ((sizeof (char *) * 3));
+	iNrOfTools = sizeof ( toolsArray ) / ( sizeof ( structTools ) );
 	if (iIndex > iNrOfTools-1)
 		return QString();
 
@@ -519,12 +518,12 @@ QValueList<Utils::toolsPaths *>Utils::scanSystem()
 	uint t, iNrOfTools;
 	// All external Tools are defined in global.h
 	struct structTools { 
-		char *pExecutableName;
-		char *pDisplayName;
-		char *pDescription;
+		char pExecutableName[16];
+		char pDisplayName[16];
+		char pDescription[1024];
 	};
 	const structTools toolsArray[] = { EXTERNAL_TOOLS };
-	iNrOfTools = sizeof (toolsArray) / ((sizeof (char *) * 3));
+	iNrOfTools = sizeof ( toolsArray ) / ( sizeof ( structTools ) );
 
 	// Note at this point if there were entries in thelist they ought to be deleted already.
 	listToolsPaths.clear();
@@ -548,9 +547,9 @@ bool Utils::isMandatory(uint iIndex)
 {
 	// All external Tools are defined in global.h
 	struct structTools { 
-		char *pExecutableName;
-		char *pDisplayName;
-		char *pDescription;
+		char pExecutableName[16];
+		char pDisplayName[16];
+		char pDescription[1024];
 	};
 	const structTools toolsArray[] = { EXTERNAL_TOOLS };
 	if (QString (toolsArray[iIndex].pDescription).find ("Mandatory") > -1)
